Represents book dimensions with width, height, and measurement unit.
Summary
Functions
Creates a Dimensions struct from API response data.
Represents book dimensions with width, height, and measurement unit.
Creates a Dimensions struct from API response data.